@@ -2,11 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_groups.pl,v 1.7 2004/06/26 10:04:14 yeupou Exp $
+# $Id: sv_groups.pl,v 1.8 2004/09/22 08:11:49 yeupou Exp $
 #
-#  Copyright 2001 (c) Loic Dachary <loic@gnu.org> (sv_cvs.pl)
-#            2003 (c) Mathieu Roy <yeupou@gnu.org> 
-#            2004 (c) Mathieu Roy <yeupou@gnu.org>
+#  Copyright 2001      (c) Loic Dachary <loic--at--gnu.org> (sv_cvs.pl)
+#            2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org> 
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -63,6 +62,8 @@ my $getopt;
 my $help;
 my $debug;
 my $cron;
+my $version = GetVersion();
+
 my $no_etc = 0;
 my $no_cvs = 0; 
 my $no_homepage = 0;
@@ -102,8 +103,8 @@ Normally, sv_users should run just after.
       --no-download            Do not update download dirs
       --one-group              Do not create a group called web<name>,
                                but only one group.
-  
-Authors: Loic Dachary <loic\@gnu.org>, Mathieu Roy <yeupou\@gnu.org>
+
+Savane version: $version
 EOF
 exit(1);
 }
