@@ -2,11 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_update_conf.pl,v 1.24 2004/08/24 06:21:37 yeupou Exp $
+# $Id: sv_update_conf.pl,v 1.25 2004/09/22 08:11:50 yeupou Exp $
 #
-#
-#
-#  Copyright 2002-2003 (c) Mathieu Roy <yeupou@gnu.org>
+#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -21,10 +19,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-#
-#
-#
-#
 
 ##
 ## This script permit to create a configuration file. As a
@@ -235,22 +229,20 @@ if ($recreate) {
     ## GUI ##
 
       AskSetting("sys_name", "Platform name", "Name shown on public pages for the whole service", "Savannah", $sys_name, 1);
-      AskSetting("sys_unix_group_name", "Server administration project unix name", "Unix group name of the meta-project used for administration", "savannah", $sys_unix_group_name);
+      AskSetting("sys_unix_group_name", "Server administration project unix name", "Unix group name of the meta-project used for administration. Take care to avoid conflicts with group name existing on your system, take care to select a valid unix group name: no checks will be done for this project unix group name.", "savannah", $sys_unix_group_name);
 
       AskSetting("sys_default_locale", "Default locale", "It must be a valid locale name", "french", $sys_default_locale);
       AskSetting("sys_datefmt", "Date format", "Date formatting. If you want to use the default locale formating, comment out (it's usually a good idea)", "Y-M-d H:i", $sys_datefmt);
 
       AskSetting("sys_themedefault", "Default theme", "--", "savannah", $sys_themedefault);
-      AskSetting("sys_logo_name", "Logo name", "The engine will search for a file like savannah/frontend/php/images/\$theme.theme/\$sys_logo_name", "floating.png", $sys_logo_name);
-      AskSetting("sys_logo_name_width", "Logo width", "In pixel", "150", $sys_logo_name_width);
-      AskSetting("sys_logo_name_height", "Logo heigth", "In pixel", "130", $sys_logo_name_height);
+      AskSetting("sys_logo_name", "Logo name", "The engine will search for a file like savannah/frontend/php/images/\$theme.theme/\$sys_logo_name. If you do not want any logo, comment out", "floating.png", $sys_logo_name);
 
 
     ## MAIL, MAILING-LIST ##
 
-      AskSetting("sys_mail_domain", "Mail domain", "--", "gnu.org", $sys_nglists_domain);
-      AskSetting("sys_mail_admin", "Admin mail address", "The mail domain we'll be added to this username", "savannah-hackers", $sys_admin_list);
-      AskSetting("sys_mail_replyto", "Default reply-to address", "--", "nobody", $sys_replyto);
+      AskSetting("sys_mail_domain", "Mail domain", "--", "gnu.org, \$sys_default_domain", $sys_mail_domain);
+      AskSetting("sys_mail_admin", "Admin mail address", "The mail domain we'll be added to this username", "savannah-hackers", $sys_mail_admin);
+      AskSetting("sys_mail_replyto", "Default reply-to address", "--", "noreply", $sys_replyto);
       AskSetting("sys_mail_list", "[BACKEND SPECIFIC] List of emails", "If you do not want such file to be updated by the backend, comment out", "/etc/email-addresses", $sys_mail_list);
       AskSetting("sys_mail_aliases", "[BACKEND SPECIFIC] List of emails aliases", "If you do not want such file to be updated by the backend, comment out", "/etc/aliases", $sys_mail_aliases);
 
@@ -268,22 +260,29 @@ if ($recreate) {
     
     ## CRONJOBS ##
     
-    AskSetting("sys_cron_users", "[BACKEND SPECIFIC] Cron job: related to users", "If you do not want your system to be synchronized with database automatically regarding to users infos (/home/$user), comment out", "yes", $sys_cron_users);
-    AskSetting("sys_cron_groups", "[BACKEND SPECIFIC] Cron job: related to groups/projects", "If you do not want your system to be synchronized with database automatically regarding to groups infos, comment out", "yes", $sys_cron_groups);
+    AskSetting("sys_cron_users", "[BACKEND SPECIFIC] Cron job: related to users", "If you do not want your system to be synchronized with database automatically regarding to users infos (/home/$user, /etc/passwd)), comment out", "yes", $sys_cron_users);
+    AskSetting("sys_cron_groups", "[BACKEND SPECIFIC] Cron job: related to groups/projects", "If you do not want your system to be synchronized with database automatically regarding to groups infos (/etc/group), comment out", "yes", $sys_cron_groups);
   
     AskSetting("sys_cron_viewcvs_forbidden", "[BACKEND SPECIFIC] Cron job: related to viewcvs ignore list", "If you do not want your system to be synchronized with database automatically regarding to viewcvs forbidden list, comment out", "yes", $sys_cron_viewcvs_forbidden);  
   
-  AskSetting("sys_cron_mail", "[BACKEND SPECIFIC] Cron job: related to mails", "If you do not want your system to be synchronized with database automatically regarding to mail infos (/etc/aliases...), comment out", "yes", $sys_cron_mail);  
-    AskSetting("sys_cron_cleaner", "[BACKEND SPECIFIC] Cron job: database cleaning", "A special backend script will clean regularly the database. If you do not want that cleaning to be done, comment out. It is recommended to use it, even if your installation use no other backend tool", "yes", $sys_cron_cleaner);  
+    AskSetting("sys_cron_mail", "[BACKEND SPECIFIC] Cron job: related to mails", "If you do not want your system to be synchronized with database automatically regarding to mail infos (/etc/aliases...), comment out", "yes", $sys_cron_mail);  
+    AskSetting("sys_cron_mailman", "[BACKEND SPECIFIC] Cron job: related to mailman", "If you do not want your system to be synchronized with database automatically regarding to mailman list (it assume you have mailman installed on this system), comment out", "yes", $sys_cron_mailman); 
+    AskSetting("sys_cron_cleaner", "[BACKEND SPECIFIC] Cron job: database cleaning", "A special backend script will clean regularly the database. If you do not want that cleaning to be done, comment out. It is recommended to use it, even if your installation use no other backend tool", "yes", $sys_cron_cleaner);
+    AskSetting("sys_cron_reminder", "[BACKEND SPECIFIC] Cron job: trackers reminder", "A special backend script will check regularly the database and send email to users in defined cases. An user can decide to receive regularly task assigned to him in a batch ; a project administrator can decide to make people that got item with high priority not closed receiving a batch. Also, when an item is supposed to start of to finish, a reminder should be sent to anybody supposed to get notification for the item", "yes", $sys_cron_reminder);  
 
 
     ## EXTRA FEATURES ##
 
+	# Ignore by default questions related to
+        # webalizer and mrtg integration. These are nowadays useless,
+        # since apache is no longer supposed to be able to this kind of
+        # data, for security reasons, on most installations.
+
       AskSetting("sys_viewcvs_conffile", "[BACKEND SPECIFIC] Viewcvs configuration file", "Path to the viewcvs conffile. If you do not use viewcvs or if you do not want the fordibben setting of this configuration file to be edit by Savannah, comment out", "/etc/viewcvs/viewcvs.conf", $sys_viewcvs_conffile);
-      AskSetting("sys_webalizer_dir", "Statistics: webalizer dir", "Where webalizer store its output. If you do not have webalizer, comment out", "/subversions/sv/src/savannah/www/webalizer", $sys_webalizer_dir);
-      AskSetting("sys_webalizer_url", "Statistics: webalizer url", "http url for webalizer output. If you do not have webalizer, comment out", "http://savannah.gnu.org/webalizer", $sys_webalizer_url);
-      AskSetting("sys_mrtg_dir", "Statistics: mrtg dir", "Where mrtg store its output. If you do not have mrtg, comment out", "/home/www/html/mrtg", $sys_mrtg_dir);
-      AskSetting("sys_mrtg_url", "Statistics: mrtg url", "http url for webalizer output. If you do not have mrtg, comment out", "http://subversions.gnu.org/mrtg", $sys_mrtg_url);
+      #AskSetting("sys_webalizer_dir", "Statistics: webalizer dir", "Where webalizer store its output. If you do not have webalizer, comment out", "/subversions/sv/src/savannah/www/webalizer", $sys_webalizer_dir);
+      #AskSetting("sys_webalizer_url", "Statistics: webalizer url", "http url for webalizer output. If you do not have webalizer, comment out", "http://savannah.gnu.org/webalizer", $sys_webalizer_url);
+      #AskSetting("sys_mrtg_dir", "Statistics: mrtg dir", "Where mrtg store its output. If you do not have mrtg, comment out", "/home/www/html/mrtg", $sys_mrtg_dir);
+      #AskSetting("sys_mrtg_url", "Statistics: mrtg url", "http url for webalizer output. If you do not have mrtg, comment out", "http://subversions.gnu.org/mrtg", $sys_mrtg_url);
       AskSetting("sys_use_google", "Google search", "Add a search via google option to the search module. If you do not want this search facility, comment out", "", $sys_use_google);
 
       AskSetting("sys_localdoc_file", "Local Administration Documentation File", "Will make available the content of a specific file to site admins. Give the path to the file or comment out", "", $sys_localdoc_file);
@@ -302,15 +301,10 @@ if ($recreate) {
     # print the conffile
     print $handle <<EOF;
 #!/usr/bin/perl
-# This file is part of the Savane project
-# <http://gna.org/projects/savane/>
 #
-# $Id: sv_update_conf.pl,v 1.24 2004/08/24 06:21:37 yeupou Exp $
+# Savane Site Configuration:
 #
-#
-# Savannah Site Configuration:
-# Configuration file for a Savannah server
-#/projects/savannah
+# $Id: sv_update_conf.pl,v 1.25 2004/09/22 08:11:50 yeupou Exp $
 #
 # This file has been generated by sv_update_conf
 # If you modify it, run sv_update_conf --update
@@ -414,10 +408,7 @@ use strict;
       # savannah/www/images/\$theme.theme/$sys_logo_name
       # Ex: "savannah", "floating.png", "150", "130"
       $sys_themedefault
-      $sys_logo_name
-      $sys_logo_name_width
-      $sys_logo_name_height
-      
+      $sys_logo_name      
 
     ## MAIL, MAILING-LIST ##
 
@@ -483,7 +474,9 @@ use strict;
       $sys_cron_groups
       $sys_cron_viewcvs_forbidden
       $sys_cron_mail
+      $sys_cron_mailman
       $sys_cron_cleaner
+      $sys_cron_reminder
 
     
     ## EXTRA FEATURES ##
@@ -519,21 +512,11 @@ use strict;
       # settings from the original SF code that does not seems usable nor 
       # usefull. They are needed in order for the PHP frontend to run for now.$s
       our \$sys_urlroot=\"\$sys_topdir/frontend/php\"\;
-      our \$sys_default_dir=\"\$sys_url_topdir\"\;
-      our \$sys_nglists_domain=\"\$sys_mail_domain\"\;
       our \$sys_replyto=\"\$sys_mail_replyto\"\;
       our \$sys_admin_list=\"\$sys_mail_admin\"\;
-      our \$sys_shell_host=\"\$sys_default_domain\"\;
-      our \$sys_users_host=\"\$sys_default_domain\"\;
-      our \$sys_docs_host=\"\$sys_default_domain\"\;    
-      our \$sys_dns1_host=\"\$sys_default_domain\"\;
-      our \$sys_dns2_host=\"\$sys_default_domain\"\;
-      our \$sys_lists_host=\"\$sys_default_domain\"\;
-      our \$sys_lists_domain=\"\$sys_nglists_domain\"\;
+      our \$sys_lists_domain=\"\$sys_default_domain\"\;
       our \$sys_email_adress=\"\$sys_mail_admin\\\@\$sys_mail_domain\"\;
-      our \$sys_server=\"\$sys_default_domain\"\;
-      # where are themes (original theme system). Shouldnt be modified
-      our \$sys_themeroot=\"\$sys_urlroot/themes/\"\;
+      our \$sys_email_address=\"\$sys_email_adress\"\;
 
 # END
 EOF
