@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: 404.php,v 1.19 2004/03/13 18:22:05 yeupou Exp $
+// $Id: 404.php,v 1.21 2004/09/23 14:53:40 yeupou Exp $
 //
 // Copyright 1999-2000 (c) The SourceForge Crew
 //
@@ -27,33 +27,14 @@
 require "./include/pre.php";
 require_directory("search");
 
-$HTML->header(array(title=>_("Requested Page not Found (Error 404)")));
-
-print "<h1>";
-if (session_issecure()) 
-{
-  print "<a href=\"https://$GLOBALS[sys_https_host]\">";
-} 
-else 
-{
-  print "<a href=\"http://$GLOBALS[sys_default_domain]\">";
-}
-
-print "Error 404: page not found</a></h1>";
-
-print "<p>";
-print html_image("404.png",array('width'=>'350', 'height'=>'215', 'alt'=>'oopps !'));
-
-print "The web page you are trying to access doesn't exist on ".$GLOBALS['HTTP_HOST'].".<br>";
-print "If you think that there's a broken link on ".$GLOBALS['HTTP_HOST']." that must be repaired, write us a word, mentioning concerned page, on the <A HREF=\"/support/?func=additem&amp;group=".$GLOBALS['sys_unix_group_name']."\">[ Support Manager ]</a>.";
-print "<p>";
+site_header(array('title'=>_("Requested Page not Found (Error 404)")));
 
 
-$HTML->box1_top('Search on '.$GLOBALS['sys_name']);
-search_box();
-$HTML->box1_bottom();
+print '<p class="warn">'.sprintf(_("The web page you are trying to access doesn't exist on %s."), $GLOBALS['sys_name']).'</p>';
+print '<p>'.sprintf(_("If you think that there's a broken link on %s that must be repaired, %s, mentioning the url your tried to access (%s)."), $GLOBALS['sys_name'], utils_link($GLOBALS['sys_home'].'support/?group='.$GLOBALS['sys_unix_group_name'],_("fill a support request")) , $_SERVER['REQUEST_URI']).'</p>';
+
+print '<p>'.sprintf(_("Otherwise, you can return to the %s %s."), $GLOBALS['sys_name'], utils_link($GLOBALS['sys_home'], _("main page"))).'</p>';
 
-print "<p>";
 
 $HTML->footer(array());
 
