@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: html.php,v 1.51 2004/06/26 11:50:42 yeupou Exp $
+# $Id: html.php,v 1.52 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #                          Mathieu Roy <yeupou--at--gnu.org>
 #
-#  Copyright 2004      (c) ...
+#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -24,6 +24,24 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+function html_splitpage ($how)
+{
+  if ($how == 'start' || $how == '1')
+    {
+      return "\n".'<div class="splitright">'."\n";
+      
+    }
+  elseif ($how == 'middle' || $how == '2')
+    {
+      return  "\n".'</div><!-- end  splitright -->'."\n".
+	'<div class="splitleft">'."\n";
+
+    }
+  else 
+    {
+      return "\n".'</div><!-- end  splitleft -->'."\n";
+    }
+}
 
 function html_nextprev ($search_url, $rows, $rows_returned)
 {
@@ -32,17 +50,17 @@ function html_nextprev ($search_url, $rows, $rows_returned)
 
   if (($rows_returned > $rows) || ($offset != 0))
     {
-      print "\n<br><h5 align=\"center\">\n";
+      print "\n<br /><h5 align=\"center\">\n";
 
       if ($offset != 0)
 	{
 	  print '<a href="'.$search_url.'&amp;offset='.($offset-$rows).'&amp;max_rows='.$max_rows.'">';
-	  print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previous.png" border="0" alt="'._("Previous Results").'">'._("Previous Results").'</a>';
+	  print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previous.png" border="0" alt="'._("Previous Results").'" />'._("Previous Results").'</a>';
 
 	}
       else
 	{
-	  print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previousgrey.png" border="0" alt="'._("Previous Results").'"><font class="italic">'._("Previous Results").'</font>';
+	  print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previousgrey.png" border="0" alt="'._("Previous Results").'" /><font class="italic">'._("Previous Results").'</font>';
 	}
 
       print "&nbsp; &nbsp; &nbsp;";
@@ -50,11 +68,11 @@ function html_nextprev ($search_url, $rows, $rows_returned)
       if ($rows_returned > $rows)
 	{
 	  print '<a href="'.$search_url.'&amp;offset='.($offset+$rows).'&amp;max_rows='.$max_rows.'">';
-	  print _("Next Results").' <img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/next.png" border="0" alt="'._("Next Results").'"></a>';
+	  print _("Next Results").' <img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/next.png" border="0" alt="'._("Next Results").'" /></a>';
 	}
       else
 	{
-	  print '<font class="italic">'._("Next Results").'</font> <img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/nextgrey.png" border="0" alt="'._("Next Results").'">';
+	  print '<font class="italic">'._("Next Results").'</font> <img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/nextgrey.png" border="0" alt="'._("Next Results").'" />';
 	}
 
       print "</h5>\n";
@@ -75,7 +93,7 @@ function html_feedback_top()
   if ($GLOBALS[ffeedback])
     {  print '<h3 class="feedbackerror">'.htmlentities($GLOBALS[ffeedback]).'</h3>'; }
   if ($GLOBALS[sys_debug_on] && $GLOBALS[debug])
-    {  print '<h3 class="feedbackerror">DEBUG information: '.htmlentities($GLOBALS[debug]).'</h3>'; }
+    {  print '<h3 class="debug">DEBUG information: '.$GLOBALS[debug].'</h3>'; }
   # yeupou@gnu.org 2003-11-03:
   # We unset feedback so there will be a bottom feedback only if something
   # changed. It may confuse users, however I would find more confusing to
@@ -94,57 +112,50 @@ function html_feedback_bottom()
   if ($GLOBALS[ffeedback])
     {  print '<h3 class="feedbackerror">'.htmlentities($GLOBALS[ffeedback]).'</h3>'; }
   if ($GLOBALS[sys_debug_on] && $GLOBALS[debug])
-    {  print '<h3 class="feedbackerror">DEBUG information: '.htmlentities($GLOBALS[debug]).'</h3>'; }
+    {  print '<h3 class="debug">DEBUG information: '.htmlentities($GLOBALS[debug]).'</h3>'; }
 }
 
-function html_a_group($grp)
-{
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_a_group($grp) ';
-  print '<A href="'.$GLOBALS['sys_home'].'project/?group_id='.$grp.'">' . group_getname($grp) . '</A>';
-}
 
-function html_blankimage($height,$width)
-{
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_blankimage($height,$width) ';
-  return html_image('blank.png',array('height'=>$height,'width'=>$width,'alt'=>' '));
-}
 
-function html_image($src,$args,$display=1)
+function html_image ($src,$args,$display=1)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_image($src,$args,$display=1) ';
-  GLOBAL $img_size;
+  GLOBAL $img_attr;
   $return = ('<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$src.'"');
   reset($args);
   while(list($k,$v) = each($args))
-    {
+    { 
       $return .= ' '.$k.'="'.$v.'"';
     }
 
   # ## insert a border tag if there isn't one
   if (!$args['border']) $return .= (' border="0"');
 
+
   # ## if no height AND no width tag, insert em both
   if (!$args['height'] && !$args['width'])
     {
-      /* Check to see if we've already fetched the image data */
-      if($img_size){
-	if(!$img_size[$src] && is_file($GLOBALS['sys_urlroot'].'images/'.$src)){
-	  $img_size[$src] = @getimagesize($GLOBALS['sys_urlroot'].'images/'.$src);
-	}
-      }
-      else
-	{
-	  if(is_file($GLOBALS['sys_urlroot'].'images/'.$src)){
-	    $img_size[$src] = @getimagesize($GLOBALS['sys_urlroot'].'images/'.$src);
-	  }
-	}
-      $return .= ' ' . $img_size[$src];
-    }
 
-  # ## insert alt tag if there isn't one
+     #Check to see if we've already fetched the image data 
+ if(!$img_attr[$src] && is_file($GLOBALS['sys_urlroot'].'/images/'.SV_THEME.'.theme/'.$src))
+   {
+     list($width, $height, $type, $img_attr[$src]) = @getimagesize($GLOBALS['sys_urlroot'].'/images/'.SV_THEME.'.theme/'.$src);
+     
+   }
+ else
+   {
+     if (is_file($GLOBALS['sys_urlroot'].'/images/'.SV_THEME.'.theme/'.$src))
+       {
+	 list($width, $height, $type, $img_attr[$src])  = @getimagesize($GLOBALS['sys_urlroot'].'/images/'.SV_THEME.'.theme/'.$src);
+       }
+   }
+ $return .= ' ' . $img_attr[$src];
+}
+
+# ## insert alt tag if there isn't one
   if (!$args['alt']) $return .= " alt=\"$src\"";
 
-  $return .= ('>');
+  $return .= (' />');
   if ($display)
     {
       print $return;
@@ -155,13 +166,6 @@ function html_image($src,$args,$display=1)
     }
 }
 
-function html_get_timezone_popup ($title='timezone',$selected='xzxzxzx')
-{
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_get_timezone_popup ';
-  global $TZs;
-  return html_build_select_box_from_arrays ($TZs,$TZs,$title,$selected,false);
-}
-
 function html_build_list_table_top ($title_arr,$links_arr=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_list_table_top ';
@@ -243,7 +247,7 @@ function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz
 	  $return .= "\n\t\t<option value=\"" . $vals[$i] . "\"";
 	  if ($vals[$i] == $checked_val)
 	    {
-	      $return .= ' selected';
+	      $return .= ' selected="selected"';
 	    }
 	}
       else
@@ -251,7 +255,7 @@ function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz
 	  $return .= "\n\t\t<option value=\"" . $i .'"';
 	  if ($i == $checked_val)
 	    {
-	      $return .= ' selected';
+	      $return .= ' selected="selected"';
 	    }
 	}
       $return .= '>'.$vals[$i].'</option>';
@@ -295,50 +299,56 @@ function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_v
 
 		The 8th parameter is optional - what to call the 'Any row' defaults to nAny	*/
 
+
+
   $return .= '
-		<SELECT NAME="'.$select_name.'">';
+		<select name="'.$select_name.'">';
 
 
   #we don't always want the default any  row shown
   if ($show_any)
     {
-      $selected = ( $checked_val == 0 ? 'SELECTED':'');
+      $selected = ( $checked_val == 0 ? 'selected="selected"':'');
       $return .= "\n<OPTION VALUE=\"0\" $selected>$text_any </OPTION>";
     }
 
   #we don't always want the default 100 row shown
   if ($show_100)
     {
-      $selected = ( $checked_val == 100 ? 'SELECTED':'');
+      $selected = ( $checked_val == 100 ? 'selected="selected"':'');
       $return .= "\n<OPTION VALUE=\"100\" $selected>$text_100 </OPTION>";
     }
 
+
   $rows=count($vals);
   if (count($texts) != $rows)
     {
       $return .= 'ERROR - uneven row counts';
     }
 
+
+
   for ($i=0; $i<$rows; $i++)
     {
       #  uggh - sorry - don't show the 100 row and Any row
       #  if it was shown above, otherwise do show it
-      if ( (($vals[$i] != '100') && ($vals[$i] != '0')) ||
+      if ((($vals[$i] != '100') && ($vals[$i] != '0')) ||
 	   ($vals[$i] == '100' && !$show_100) ||
-	   ($vals[$i] == '0' && !$show_any) )
+	   ($vals[$i] == '0' && !$show_any))
 	{
 	  $return .= '
-				<OPTION VALUE="'.$vals[$i].'"';
+				<option value="'.$vals[$i].'"';
 	  if ($vals[$i] == $checked_val)
 	    {
-	      $return .= ' SELECTED';
+	      $return .= ' selected="selected"';
 	    }
-	  $return .= '>'.$texts[$i].'</OPTION>';
-	}
+	  $return .= '>'.$texts[$i].'</option>';
+	
+       }
 
     }
   $return .= '
-		</SELECT>';
+		</select>';
   return $return;
 }
 
@@ -395,7 +405,7 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
 	{
 	  if ($checked_array[$j] == '0')
 	    {
-	      $return .= ' SELECTED';
+	      $return .= ' selected="selected"';
 	    }
 	}
       $return .= '>'.$text_any.'</OPTION>';
@@ -412,7 +422,7 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
 	{
 	  if ($checked_array[$j] == '100')
 	    {
-	      $return .= ' SELECTED';
+	      $return .= ' selected="selected"';
 	    }
 	}
       $return .= '>'.$text_100.'</OPTION>';
@@ -434,7 +444,7 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
 	    {
 	      if ($val == $checked_array[$j])
 		{
-		  $return .= ' SELECTED';
+		  $return .= ' selected="selected"';
 		}
 	    }
 	  $return .= '>'. ($show_value?$val.'-':'').
@@ -467,31 +477,31 @@ function html_select_permission_box ($artifact, $row, $level="member")
       $value = $row[$artifact.'_flags'];
       $default = _("Group Default");
     }
-
+  
   print '
     <td>
       <select name="'.$artifact.'_user_'.$num.'">';
   if ($default)
     {
       print '
-        <option value="NULL"'.((!$value)?" selected":"").'>'.$default.'</option>';
+        <option value="NULL"'.((!$value)?" selected=\"selected\"":"").'>'.$default.'</option>';
     }
   print '
-        <option value="9"'.(($value == 9)?" selected":"").'>'._("None").'</option>';
+        <option value="9"'.(($value == 9)?" selected=\"selected\"":"").'>'._("None").'</option>';
   if ($artifact != "news")
     {
       print '
-        <option value="1"'.(($value == 1)?" selected":"").'>'._("Technician").'</option>';
+        <option value="1"'.(($value == 1)?" selected=\"selected\"":"").'>'._("Technician").'</option>';
     }
 
   print '
-        <option value="3"'.(($value == 3)?" selected":"").'>'._("Manager").'</option>';
+        <option value="3"'.(($value == 3)?" selected=\"selected\"":"").'>'._("Manager").'</option>';
 
 
   if ($artifact != "news")
     {
       print '
-        <option value="2"'.(($value == 2)?" selected":"").'>'._("Techn. & Manager").'</option>';
+        <option value="2"'.(($value == 2)?" selected=\"selected\"":"").'>'._("Techn. & Manager").'</option>';
     }
 
   print '
@@ -500,17 +510,78 @@ function html_select_permission_box ($artifact, $row, $level="member")
   if (!$value && $level == "group")
     {
       $value = group_gettypepermissions($GLOBALS[group_id], $artifact);
-      print '<br>('.
+      print '<br />('.
 	(($value == 9)?_("None"):"").
 	(($value == 1)?_("Technician"):"").
 	(($value == 3)?_("Manager"):"").
 	(($value == 2)?_("Techn. & Manager"):"").
 	')';
     }
+
   print '
     </td>';
 }
 
+
+function html_select_restriction_box ($artifact, $row, $level="group", $notd=0)
+{
+  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_select_permission_box ($artifact, $row, $level="member")';
+  # If $row['user_id'] does not exists, we havent got a row but simple value
+  # and it means that we are about to modify per group default
+  if ($level == "type")
+    {
+      $value = $row;
+      $default = 0;
+    }
+  else
+    {
+      $value = $row;
+      $default = _("Group Type Default");
+    }
+  
+  if (!$notd) 
+    {
+      print '
+    <td>';
+    }
+
+  print '
+      <select name="'.$artifact.'_restrict">';
+
+  if ($default)
+    {
+      print '
+        <option value="NULL"'.((!$value)?" selected=\"selected\"":"").'>'.$default.'</option>';
+    }
+  print '
+        <option value="5"'.(($value == 5)?" selected=\"selected\"":"").'>'._("Project Member").'</option>';
+  print '
+        <option value="3"'.(($value == 3)?" selected=\"selected\"":"").'>'._("Logged-in User").'</option>';
+  print '
+        <option value="2"'.(($value == 2)?" selected=\"selected\"":"").'>'._("Anonymous").'</option>';
+
+  print '
+      </select>';
+
+  if (!$value && $level == "group")
+    {
+      $value = group_gettyperestrictions($GLOBALS[group_id], $artifact);
+      print '<br />('.
+	(($value == 5)?_("Project Member"):"").
+	(($value == 3)?_("Logged-in User"):"").
+	(($value == 2)?_("Anonymous"):"").
+	')';
+    }
+  
+  
+  if (!$notd) 
+    {
+      print '
+    </td>';
+    }
+}
+
+
 # This function must now every type of directory that can be built by the
 # backend.
 # FIXME: in a future, we may create a table of method associating
@@ -518,17 +589,17 @@ function html_select_permission_box ($artifact, $row, $level="member")
 function html_select_typedir_box ($input_name, $current_value)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_select_typedir_box ';
-  print '<br>
+  print '<br />
       <select name="'.$input_name.'">
-        <option value="basiccvs"'.(($current_value == "basiccvs")?" selected":"").'>'._("Basic Cvs Directory").'</option>
+        <option value="basiccvs"'.(($current_value == "basiccvs")?" selected=\"selected\"":"").'>'._("Basic Cvs Directory").'</option>
         <option value="basicdirectory"'.(($current_value == "basicdirectory")?" selected":"").'>'._("Basic Directory").'</option>
-        <option value="cvsattic"'.(($current_value == "cvsattic")?" selected":"").'>'._("Cvs Attic").'</option>
+        <option value="cvsattic"'.(($current_value == "cvsattic")?" selected=\"selected\"":"").'>'._("Cvs Attic").'</option>
       </select> [BACKEND SPECIFIC]
 ';
 
   # put some information
-  print '<br><font class="italic">Basic directory will make the backend using DownloadMakeArea(), defined in Savannah::Download; <br> CVS directory will make the backend using CvsMakeArea(), defined in Savannah::Cvs;<br>
-(If you need to build directories with another method, the solution is to write a new sub in the appropriate perl module, please send a mail to savannah-dev@gnu.org to get information about that)</font><br>';
+  print '<br /><font class="italic">Basic directory will make the backend using DownloadMakeArea(), defined in Savannah::Download; <br /> CVS directory will make the backend using CvsMakeArea(), defined in Savannah::Cvs;<br />
+(If you need to build directories with another method, the solution is to write a new sub in the appropriate perl module, please send a mail to savannah-dev@gnu.org to get information about that)</font><br />';
 
 }
 
@@ -551,7 +622,7 @@ function html_select_theme_box ($input_name="user_theme", $current=0)
     {
       print "\n\t\t".'<option value="'.$theme.'"';
       if ($theme == $current)
-	{ print ' selected'; }
+	{ print ' selected="selected"'; }
       print '>'.$theme;
       if ($theme == $GLOBALS['sys_themedefault'])
 	{ print ' ('._("default").')'; }
@@ -562,14 +633,14 @@ function html_select_theme_box ($input_name="user_theme", $current=0)
   $theme = "rotate";
   print "\n\t\t".'<option value="'.$theme.'"';
   if ($theme == $current)
-    { print ' selected'; }
-  print '>'.$theme.' ('.("a different theme alphabetically picked everyday").')</option>';
+    { print ' selected="selected"'; }
+  print '> &gt; '.("alphabetically picked everyday").'</option>';
   # special random case
   $theme = "random";
   print "\n\t\t".'<option value="'.$theme.'"';
   if ($theme == $current)
-    { print ' selected'; }
-  print '>'.$theme.' ('.("a different theme randomly picked everyday").')</option>';
+    { print ' selected="selected"'; }
+  print '> &gt; '.("randomly picked everyday").'</option>';
   print "		</select>\n";
 
 }
@@ -584,23 +655,23 @@ function html_build_priority_select_box ($name='priority', $checked_val='5')
     ?>
      <SELECT NAME="<?php print $name; ?>">
 	<OPTION VALUE="1"<?php if ($checked_val=="1")
-	  {print " SELECTED";} ?>>1 - Lowest</OPTION>
+	  {print " selected=\"selected\"";} ?>>1 - Lowest</OPTION>
 				    <OPTION VALUE="2"<?php if ($checked_val=="2")
-				      {print " SELECTED";} ?>>2</OPTION>
+				      {print " selected=\"selected\"";} ?>>2</OPTION>
 								<OPTION VALUE="3"<?php if ($checked_val=="3")
-								  {print " SELECTED";} ?>>3</OPTION>
+								  {print " selected=\"selected\"";} ?>>3</OPTION>
 											    <OPTION VALUE="4"<?php if ($checked_val=="4")
-											      {print " SELECTED";} ?>>4</OPTION>
+											      {print " selected=\"selected\"";} ?>>4</OPTION>
 															<OPTION VALUE="5"<?php if ($checked_val=="5")
-															  {print " SELECTED";} ?>>5 - Medium</OPTION>
+															  {print " selected=\"selected\"";} ?>>5 - Medium</OPTION>
 																		    <OPTION VALUE="6"<?php if ($checked_val=="6")
-																		      {print " SELECTED";} ?>>6</OPTION>
+																		      {print " selected=\"selected\"";} ?>>6</OPTION>
 																						<OPTION VALUE="7"<?php if ($checked_val=="7")
-																						  {print " SELECTED";} ?>>7</OPTION>
+																						  {print " selected=\"selected\"";} ?>>7</OPTION>
 																									    <OPTION VALUE="8"<?php if ($checked_val=="8")
-																									      {print " SELECTED";} ?>>8</OPTION>
+																									      {print " selected=\"selected\"";} ?>>8</OPTION>
 																													<OPTION VALUE="9"<?php if ($checked_val=="9")
-																													  {print " SELECTED";} ?>>9 - Highest</OPTION>
+																													  {print " selected=\"selected\"";} ?>>9 - Highest</OPTION>
 																																    </SELECT>
 																																    <?php
 
