@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: forum.php,v 1.4 2004/03/13 18:22:06 yeupou Exp $
+# $Id: forum.php,v 1.6 2004/09/23 12:16:34 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -135,7 +135,7 @@ function forum_header($params)
                 {	
                     $is_news=0;
                     #echo '<font class="error">'._("Error").' - '._("This news item was not found").'</font>';
-                    #echo "forum_name=$forum_name<br>";
+                    #echo "forum_name=$forum_name<br />";
                     site_project_header($params);
                     #site_project_header(array('group'=>$group_id,'toptab'=>'forum'));	
                 } 
@@ -314,7 +314,7 @@ function show_thread($thread_id,$et=0)
                     $total_rows++;
                     $ret_val .= '<TR class="'. utils_get_alt_row_color($total_rows) .'"><TD>'. 
                         (($current_message != db_result($result, $i, 'msg_id'))?'<A HREF="'.$GLOBALS['sys_home'].'forum/message.php?msg_id='.db_result($result, $i, 'msg_id').'">':'').
-                        '<IMG SRC="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/mail.png" BORDER=0 HEIGHT=12 WIDTH=12> ';
+                        '<IMG SRC="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/mail.png" BORDER=0 HEIGHT=12 WIDTH=12 /> ';
                     /*
 				See if this message is new or not
                     */
@@ -384,7 +384,7 @@ function show_submessages($thread_id, $msg_id, $level,$et=0)
                 }
 
 
-            $ret_val .= '<IMG SRC="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/mail.png" BORDER=0 HEIGHT=12 WIDTH=12> ';
+            $ret_val .= '<IMG SRC="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/mail.png" BORDER=0 HEIGHT=12 WIDTH=12 /> ';
 			
 			/*
 				If it this is the message being displayed, don't show a link to it
@@ -601,7 +601,7 @@ function show_post_form($forum_id, $thread_id=0, $is_followup_to=0, $subject="")
 			echo '</td></tr>';
 			echo '<tr><td colspan="2" align="MIDDLE">';
 			echo '<font class="warn">HTML tags will display in your post as text</font>';
-			echo '<br>';
+			echo '<br />';
 			echo '<input type="SUBMIT" name="SUBMIT" value="'._("Post Comment").'">';
 			echo '</td></tr></table>';
 			echo '</form>';
@@ -689,16 +689,16 @@ function handle_monitoring($forum_id,$msg_id)
                             $savannah_artifact=0; # these must stay zero to not mess up the subject any further
                             $savannah_artifact_id=0;
                             $reply_to=$GLOBALS['sys_lists_prefix'] . db_result($result,0,'unix_group_name').
-                                "_" . db_result($result,0,'forum_name') . "@" . $GLOBALS['sys_default_domain'];
+                                "_" . db_result($result,0,'forum_name') . "@" . $GLOBALS['sys_mail_domain'];
                             $additional_headers="BCC: $tolist";
 
 # Custom extensions to the header:
 /*
-                            echo "Just executed <br>".
-                            "sendmail_mail (from: $from, <br>to: $to, <br>subject: $subject, <br>message: $message, <br>".
-                                           "savannah_project: $savannah_project, <br>savannah_artifact: $savannah_artifact,<br>".
-                                           "savannah_artifact_id: $savannah_artifact_id, <br>reply_to: $reply_to,<br>".
-                                           "additional_headers: $additional_headers<br>";
+                            echo "Just executed <br />".
+                            "sendmail_mail (from: $from, <br />to: $to, <br />subject: $subject, <br />message: $message, <br />".
+                                           "savannah_project: $savannah_project, <br />savannah_artifact: $savannah_artifact,<br />".
+                                           "savannah_artifact_id: $savannah_artifact_id, <br />reply_to: $reply_to,<br />".
+                                           "additional_headers: $additional_headers<br />";
 */
                             
                             sendmail_mail ($from, $to, $subject, $message, 
