@@ -1,32 +1,31 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: skill.php,v 1.4 2004/03/03 19:11:35 toddy Exp $
-//
-//
-// Copyright 1999-2000 (c) The SourceForge Crew
-//
-//
-//  Copyright 2000-2003 (c) Free Software Foundation
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: skill.php,v 1.5 2004/03/13 18:22:06 yeupou Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2000-2003 (c) Free Software Foundation
+#
+#  Copyright 2004      (c) ...
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+#
+#
+#
+#
 
 function people_skill_box($name='skill_id',$checked='xyxy')
 {
@@ -34,7 +33,7 @@ function people_skill_box($name='skill_id',$checked='xyxy')
   global $PEOPLE_SKILL;
   if (!$PEOPLE_SKILL)
     {
-      //will be used many times potentially on a single page
+      #will be used many times potentially on a single page
       $sql="SELECT * FROM people_skill ORDER BY name ASC";
       $PEOPLE_SKILL=db_query($sql);
     }
@@ -47,7 +46,7 @@ function people_skill_level_box($name='skill_level_id',$checked='xyxy')
   global $PEOPLE_SKILL_LEVEL;
   if (!$PEOPLE_SKILL_LEVEL)
     {
-      //will be used many times potentially on a single page
+      #will be used many times potentially on a single page
       $sql="SELECT * FROM people_skill_level";
       $PEOPLE_SKILL_LEVEL=db_query($sql);
     }
@@ -60,7 +59,7 @@ function people_skill_year_box($name='skill_year_id',$checked='xyxy')
   global $PEOPLE_SKILL_YEAR;
   if (!$PEOPLE_SKILL_YEAR)
     {
-      //will be used many times potentially on a single page
+      #will be used many times potentially on a single page
       $sql="SELECT * FROM people_skill_year";
       $PEOPLE_SKILL_YEAR=db_query($sql);
     }
@@ -73,12 +72,12 @@ function people_add_to_skill_inventory($skill_id,$skill_level_id,$skill_year_id)
   global $feedback;
   if (user_isloggedin())
     {
-      //check if they've already added this skill
+      #check if they've already added this skill
       $sql="SELECT * FROM people_skill_inventory WHERE user_id='". user_getid() ."' AND skill_id='$skill_id'";
       $result=db_query($sql);
       if (!$result || db_numrows($result) < 1)
 	{
-	  //skill not already in inventory
+	  #skill not already in inventory
 	  $sql="INSERT INTO people_skill_inventory (user_id,skill_id,skill_level_id,skill_year_id) ".
 	     "VALUES ('". user_getid() ."','$skill_id','$skill_level_id','$skill_year_id')";
 	  $result=db_query($sql);
@@ -190,8 +189,8 @@ function people_edit_skill_inventory($user_id)
 	}
 
     }
-  //add a new skill
-  $i++; //for row coloring
+  #add a new skill
+  $i++; #for row coloring
 
   echo '
 	<tr><td colspan="4"><h3>'._("Add A New Skill").'</h3></td></tr>
