@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: pre.php,v 1.76 2004/07/03 18:22:03 yeupou Exp $
+# $Id: pre.php,v 1.77 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -23,9 +23,17 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-# Defines all of the Savannah hosts, databases, etc.
+# Defines all of the Savane hosts, databases, etc.
 # This needs to be loaded first because the lines below depend upon it.
-require getenv('SV_LOCAL_INC_PREFIX').'/savannah.conf.php';
+if (getenv('SAVANE_CONF'))
+{ require getenv('SAVANE_CONF').'/savannah.conf.php'; }
+elseif (getenv('SV_LOCAL_INC_PREFIX'))
+{ require getenv('SV_LOCAL_INC_PREFIX').'/savannah.conf.php'; }
+else 
+{ 
+  # go back to default location
+  require '/etc/savannah/savannah.conf.php';
+}
 
 if ($GLOBALS['sys_url_topdir'] != '/')
 {
@@ -36,12 +44,18 @@ else
   $sys_home = $GLOBALS['sys_url_topdir'];
 }
 
-# Defines the https url, if available
+# Defines the https url, if available -- no path is added since this
+# variable can be used with REQUEST_URI added.
 if (isset($GLOBALS['sys_https_host'])) 
-{ $sys_https_url = 'https://'.$GLOBALS['sys_https_host'].$GLOBALS['sys_url_topdir']; } 
+{ 
+  $sys_https_url = 'https://'.$GLOBALS['sys_https_host'];
+} 
 else
-{ $sys_https_url = 'http://'.$GLOBALS['sys_default_domain'].$GLOBALS['sys_url_topdir']; }
-;
+{ 
+  $sys_https_url = 'http://'.$GLOBALS['sys_default_domain'];
+}
+
+
 
 # require_directory
 # sources (requires) all specific include files of a module from
