@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sendmail.php,v 1.12 2004/09/22 08:11:51 yeupou Exp $
+# $Id: sendmail.php,v 1.13 2004/09/29 10:39:53 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -120,7 +120,8 @@ function sendmail_mail ($from,
   # Add eventually info on the subject
   if ($savannah_artifact && $savannah_artifact_id) 
     { 
-       $subject = "[".$savannah_artifact." #".$savannah_artifact_id."] ".$subject; }
+       $subject = "[".$savannah_artifact." #".$savannah_artifact_id."] ".$subject; 
+    }
  
    # Remove the extra ", " at the end of the list
    $real_to = substr($real_to,0,-2);
