@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: session.php,v 1.23 2004/09/22 08:11:51 yeupou Exp $
+# $Id: session.php,v 1.24 2004/09/29 12:54:38 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -106,7 +106,7 @@ function session_login_valid($form_loginname,
 	  return false;
 	}
       $md5_pw = md5($form_pw);
-      db_query("UPDATE user SET unix_pw = '".account_genunixpw($form_pw)."', user_pw = '$md5_pw' WHERE user_id = ".$usr['user_id']);
+      db_query("UPDATE user SET user_pw = '$md5_pw' WHERE user_id = ".$usr['user_id']);
     }
   else if($usr['user_pw'] == 'SSH') 
     {
