@@ -2,12 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: data.php,v 1.15 2004/06/28 14:21:32 yeupou Exp $
+# $Id: data.php,v 1.17 2004/09/23 16:16:40 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
 #  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#                          Yves Perrin <yves.perrin--at--cern.ch>
 #
 #
 # This program is free software; you can redistribute it and/or
@@ -95,11 +96,11 @@ function trackers_data_get_all_fields ($group_id=false,$reload=false)
     }
 
   #Debug code
-  #echo "<br>DBG - At end of bug_get_all_fields: $rows";
+  #print "<br />DBG - At end of bug_get_all_fields: $rows";
   #reset($BF_USAGE_BY_NAME);
   #while (list($key, $val) = each($BF_USAGE_BY_NAME))
   #{
-  #echo "<br>DBG - $key -> use_it: $val[use_it], $val[place]";
+  #print "<br />DBG - $key -> use_it: $val[use_it], $val[place]";
   #}
 
   # rewind internal pointer of global arrays
@@ -184,49 +185,43 @@ function trackers_data_show_notification_settings($group_id, $tracker_name, $sho
       }
       if ($grtrsettings['nb_categories'] > 0) {
 	if ($show_intro_msg != 0) {
-	  echo '
-	  <P><B>As a project administrator</B> you must decide if the list of persons to be systematically notified on new '.$tracker_name.' submissions (and possibly updates)
-	  depend on the '.$tracker_name.' category or not and you must provide
-	  the corresponding email addresses (comma separated).<BR>';
+	  print '
+	  '.sprintf(_("As a project administrator you must decide if the list of persons to be systematically notified on new %s submissions (and possibly updates)
+	  depend on the categories or not and you must provide
+	  the corresponding email addresses (comma separated list)."), $tracker_name).'<br /><br />';
+
 	}
-	echo '<table><tr>
-	  <td><INPUT TYPE="RADIO" NAME="'.$tracker_name.'_notif_scope" VALUE="category" '.$categoryradio.'></td><td colspan="2">Notify persons in the category related list <b>instead of</b> the global list</td>
-	  </tr><tr>
-	  <td><INPUT TYPE="RADIO" NAME="'.$tracker_name.'_notif_scope" VALUE="both" '.$bothradio.'></td><td colspan="2">Notify persons in the category related list <b>in addition to</b> the global list</td>
-	  </tr><tr>
-	  <td><INPUT TYPE="RADIO" NAME="'.$tracker_name.'_notif_scope" VALUE="global" '.$globalradio.'></td><td colspan="2">Notify persons in the <b>global list only</b></td>
-	  </tr><tr>
-	  <td colspan="3">&nbsp;</td>
-	  </tr><tr>
-	  <td colspan="3"><h4>Category related lists</h4></td>
-	  </tr><tr>';
-	echo '<INPUT TYPE="HIDDEN" NAME="'.$tracker_name.'_nb_categories" VALUE="'.$grtrsettings['nb_categories'].'">';
-	for ($i=0; $i < $grtrsettings['nb_categories'] ; $i++) {
-	  echo '<INPUT TYPE="HIDDEN" NAME="'.$tracker_name.'_cat_'.$i.'_bug_fv_id" VALUE="'.$grtrsettings['category'][$i]['fv_id'].'">';
-	  echo '<td>&nbsp;</td><td><font class="preinput">'.$grtrsettings['category'][$i]['name'].'</font></td><td><INPUT TYPE="TEXT" NAME="'.$tracker_name.'_cat_'.$i.'_email" VALUE="'.$grtrsettings['category'][$i]['email'].'" SIZE="30" MAXLENGTH="255">
-	  &nbsp;&nbsp;&nbsp;<font class="preinput">(send on all updates)</font>
-	  <INPUT TYPE="CHECKBOX" NAME="'.$tracker_name.'_cat_'.$i.'_send_all_flag" VALUE="1" '. (($grtrsettings['category'][$i]['send_all_flag'])?'CHECKED':'') .'></td>
-	  </tr><tr>';
-	}
-	echo '
-	<td colspan="3">&nbsp;</td>
-	</tr><tr>
-	<td colspan="3"><h4>Global list</h4></td>
-	  </tr></table>';
+	print '
+           <INPUT TYPE="RADIO" NAME="'.$tracker_name.'_notif_scope" VALUE="global" '.$globalradio.' />&nbsp;&nbsp;<span class="preinput">'._("Notify persons in the global list only").'</span><br />
+          <INPUT TYPE="RADIO" NAME="'.$tracker_name.'_notif_scope" VALUE="category" '.$categoryradio.' />&nbsp;&nbsp;<span class="preinput">'._("Notify persons in the category related list instead of the global list").'</span><br />
+	  <INPUT TYPE="RADIO" NAME="'.$tracker_name.'_notif_scope" VALUE="both" '.$bothradio.' />&nbsp;&nbsp;<span class="preinput">'._("Notify persons in the category related list in addition to the global list").'</span><br />
+
+
+	  <h5>'._("Category related lists").'</h5>';
+	print '<INPUT TYPE="HIDDEN" NAME="'.$tracker_name.'_nb_categories" VALUE="'.$grtrsettings['nb_categories'].'" />';
+
+	for ($i=0; $i < $grtrsettings['nb_categories'] ; $i++) 
+	  {
+	    print '<INPUT TYPE="HIDDEN" NAME="'.$tracker_name.'_cat_'.$i.'_bug_fv_id" VALUE="'.$grtrsettings['category'][$i]['fv_id'].'" />';
+	    print '<span class="preinput">'.$grtrsettings['category'][$i]['name'].'</span><br />&nbsp;&nbsp;<INPUT TYPE="TEXT" NAME="'.$tracker_name.'_cat_'.$i.'_email" VALUE="'.$grtrsettings['category'][$i]['email'].'" SIZE="30" MAXLENGTH="255" /><br />
+
+          <span class="preinput">'._("Send on all updates:").'</span>&nbsp;&nbsp;
+	  <INPUT TYPE="CHECKBOX" NAME="'.$tracker_name.'_cat_'.$i.'_send_all_flag" VALUE="1" '. (($grtrsettings['category'][$i]['send_all_flag'])?'checked="checked"':'') .' /><br />
+';
+	  }
+
+	print '<h5>'._("Global list").'</h5>';
 
       } else {
 	if ($show_intro_msg != 0) {
-	  echo '
-	  <P><B>As a project administrator</B> you must specify the email lists (comma separated) of persons
-	  to be systematically notified on new '.$tracker_name.' submissions (and possibly updates).<BR>
-	  <INPUT TYPE="HIDDEN" NAME="'.$tracker_name.'_notif_scope" VALUE="global">
-	  ';
+	  print '
+	  '.sprintf(_("As a project administrator you must decide if the list of persons to be systematically notified on new %s submissions (and possibly updates)
+	  depend on the categories or not and you must provide
+	  the corresponding email addresses (comma separated list)."), $tracker_name).'<br /><br />';
 	}
       }
-      echo '<table><tr>
-      <td>&nbsp;</td><td colspan="2"><INPUT TYPE="TEXT" NAME="'.$tracker_name.'_new_item_address" VALUE="'.$grtrsettings['glnewad'].'" SIZE="40" MAXLENGTH="255">
-      &nbsp;&nbsp;&nbsp;<font class="preinput">(send on all updates)</font> <INPUT TYPE="CHECKBOX" NAME="'.$tracker_name.'_send_all_changes" VALUE="1" '. (($grtrsettings['glsendall'])?'CHECKED':'') .'></td>
-      </tr></table>';
+      print '<span class="preinput">'._("Carbon-Copy List:").'</span><br />&nbsp;&nbsp;<INPUT TYPE="TEXT" NAME="'.$tracker_name.'_new_item_address" VALUE="'.$grtrsettings['glnewad'].'" SIZE="40" MAXLENGTH="255"><br />
+      <span class="preinput">'._("Send on all updates:").'</span>&nbsp;&nbsp;<INPUT TYPE="CHECKBOX" NAME="'.$tracker_name.'_send_all_changes" VALUE="1" '. (($grtrsettings['glsendall'])?'CHECKED':'') .'>';
    }
 }
 
@@ -249,16 +244,16 @@ function trackers_data_post_notification_settings($group_id, $tracker_name)
   $nb_categories_name = $tracker_name."_nb_categories";
   $nb_categories = $GLOBALS[$nb_categories_name];
 
-  if ($notif_scope != "global") 
-    {
-      if ($notif_scope == "category") 
-	{ $notif_value = 0; }
-      if ($notif_scope == "both") 
-	{ $notif_value = 2; }
-      else { $notif_value = 1; }
-    } 
-  else 
-    { $notif_value = 1; }
+  if ($notif_scope != "global") {
+    if ($notif_scope == "category") {
+      $notif_value = 0;
+    }
+    if ($notif_scope == "both") {
+      $notif_value = 2;
+    }
+  } else {
+    $notif_value = 1;
+  }
 
   # set global notification info for this group
   $res_gl=db_query("UPDATE groups SET "
@@ -320,12 +315,14 @@ function trackers_data_get_item_notification_info($item_id, $artifact, $updated)
   $glnewad = db_result($result,0,"new_".$artifact."_address");
   if ($glnotif != 1) {   # if not 'global only'
     $cat_field_name = "category_id";
+
     $sql="SELECT "."$artifact"."_field_value.email_ad, "."$artifact"."_field_value.send_all_flag ".
        "FROM "."$artifact"."_field_value, "."$artifact"."_field, $artifact ".
        "WHERE "."$artifact.bug_id='$item_id' ".
-       "AND "."$artifact"."_field_value.value_id="."$artifact.category_id ".
+       "AND "."$artifact"."_field.field_name='$cat_field_name' ".
        "AND "."$artifact"."_field_value.bug_field_id="."$artifact"."_field.bug_field_id ".
-       "AND "."$artifact"."_field.field_name='$cat_field_name'";
+       "AND "."$artifact"."_field_value.group_id="."$artifact.group_id ".
+       "AND "."$artifact"."_field_value.value_id="."$artifact.category_id";
 
     $result=db_query($sql);
     $rows=db_numrows($result);
@@ -354,7 +351,7 @@ function trackers_data_get_item_notification_info($item_id, $artifact, $updated)
   if (trim($emailad) != "") {
     $sendemail = 1;
   }
-  #  echo "EMAILAD=$emailad SENDEMAIL=$sendemail";
+  #  print "EMAILAD=$emailad SENDEMAIL=$sendemail";
   return array($emailad, $sendemail);
 }
 
@@ -485,7 +482,7 @@ function trackers_data_get_field_predefined_values ($field, $group_id=false, $ch
       $sql="SELECT value_id,value,bug_fv_id,bug_field_id,group_id,description,order_id,status ".
 	 "FROM ".ARTIFACT."_field_value ".
 	 "WHERE group_id=$group_id AND bug_field_id=$field_id ".
-	 $status_cond." ORDER BY order_id ASC";
+	 $status_cond." ORDER BY order_id,value ASC";
       $res_value = db_query($sql);
       $rows=db_numrows($res_value);
 
@@ -495,7 +492,7 @@ function trackers_data_get_field_predefined_values ($field, $group_id=false, $ch
 	  $sql="SELECT value_id,value,bug_fv_id,bug_field_id,group_id,description,order_id,status ".
 	     "FROM ".ARTIFACT."_field_value ".
 	     "WHERE group_id=100 AND bug_field_id=$field_id ".
-	     $status_cond." ORDER BY order_id ASC";
+	     $status_cond." ORDER BY order_id,value ASC";
 	  $res_value = db_query($sql);
 	  $rows=db_numrows($res_value);
 	}
@@ -933,7 +930,7 @@ function trackers_data_copy_default_values($field, $group_id, $by_field_id=false
 	  $sql="INSERT INTO ".ARTIFACT."_field_value ".
 	     "(bug_field_id,group_id,value_id,value,description,order_id,status) ".
 	     "VALUES ('$field_id','$group_id','$value_id','$value','$description','$order_id','$status')";
-	  #echo "<BR>DBG - $sql";
+	  #print "<BR>DBG - $sql";
 	  $res_insert = db_query($sql);
 
 	  if (db_affected_rows($res_insert) < 1)
@@ -1003,7 +1000,7 @@ function trackers_data_create_value ($field, $group_id, $value, $description,$or
   # An empty field value is not allowed
   if (preg_match ("/^\s*$/", $value))
     {
-      fb(_("Empty field value not allowed."), 0);
+      fb(_("Empty field value not allowed"), 0);
       return;
     }
 
@@ -1069,7 +1066,7 @@ function trackers_data_update_value ($item_fv_id,$field,$group_id,$value,$descri
   # An empty field value is not allowed
   if (preg_match ("/^\s*$/", $value))
     {
-      fb(_("Empty field value not allowed."), 0);
+      fb(_("Empty field value not allowed"), 0);
       return;
     }
 
@@ -1096,7 +1093,7 @@ function trackers_data_update_value ($item_fv_id,$field,$group_id,$value,$descri
      "WHERE $where_cond";
   $result = db_query($sql);
 
-  #echo "<BR>DBG - $sql";
+  #print "<BR>DBG - $sql";
 
   if (db_affected_rows($result) < 1)
     {
@@ -1139,7 +1136,8 @@ function trackers_data_update_usage($field_name,
 				    $empty_ok=0,
 				    $keep_history=0,
 				    $show_on_add_members=0,
-				    $show_on_add=0)
+				    $show_on_add=0,
+				    $transition_default_auth='A')
 
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_update_usage';
@@ -1184,7 +1182,8 @@ function trackers_data_update_usage($field_name,
 	 "show_on_add_members='$show_on_add_members',place='$rank', ".
 	 "custom_label=$lbl,  custom_description=$desc,".
 	 "custom_display_size=$disp_size,  custom_empty_ok=$empty,".
-	 "custom_keep_history=$keep_hist ".
+	 "custom_keep_history=$keep_hist, ".
+	 "transition_default_auth='$transition_default_auth' ".
 	 "WHERE bug_field_id='$field_id' AND group_id='$group_id'";
       $result = db_query($sql);
     }
@@ -1192,7 +1191,7 @@ function trackers_data_update_usage($field_name,
     {
       $sql = 'INSERT INTO '.ARTIFACT.'_field_usage '.
 	 "VALUES ('$field_id','$group_id','$use_it','$show_on_add',".
-	 "'$show_on_add_members','$rank',$lbl,$desc,$disp_size,$empty,$keep_hist )";
+	 "'$show_on_add_members','$rank',$lbl,$desc,$disp_size,$empty,$keep_hist,'$transition_default_auth')";
       $result = db_query($sql);
     }
 
@@ -1419,11 +1418,11 @@ function trackers_data_handle_update ($group_id,
 				      &$extra_addresses)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_handle_update ';
-
-  /*
-      Update an item. Rk: vfl is an variable list of fields, Vary from one project to another
-      return true if bug updated, false if nothing changed or DB update failed
-  */
+  
+  # Update an item. Rk: vfl is an variable list of fields, Vary from one 
+  # project to another
+  # return true if bug updated, false if nothing changed or
+  # DB update failed
 
   # Make sure  required fields are not empty
   if (!$group_id || !$item_id || !$canned_response ||
@@ -1444,13 +1443,41 @@ function trackers_data_handle_update ($group_id,
       dbg("no management/techn. rights");
       exit_permission_denied();
     }
-
-  /*
-      See which fields changed during the modification
-      and if we must keep history then do it. Also add them to the update
-      statement
-  */
-
+  
+  # Extract field transitions possibilities
+  $field_transition = array();
+  $field_transition_sql = "SELECT field_id,from_value_id,to_value_id,is_allowed,assign_to,notification_list ".
+     "FROM trackers_field_transition ".
+     "WHERE group_id='".$group_id."' AND artifact='".ARTIFACT."' ";
+  
+  $field_transition_result = db_query($field_transition_sql);
+  if ($field_transition_result && db_numrows($field_transition_result) > 0) 
+    {
+      while ($this_transition = db_fetch_array($field_transition_result)) 
+	{
+	  $field_id = $this_transition['field_id'];
+	  if (!array_key_exists($field_id, $field_transition)) 
+	    { $field_transition[$field_id] = array(); }
+	  
+	  $from = $this_transition['from_value_id'];
+	  if ($from == "0")
+	    { $from = "any"; }
+	  if (!array_key_exists($from, $field_transition[$field_id])) 
+	    { $field_transition[$field_id][$from] = array(); }
+	  
+	  $to = $this_transition['to_value_id'];
+	  if (!array_key_exists($to, $field_transition[$field_id][$from])) 
+	    { $field_transition[$field_id][$from][$to] = array();  }
+	  
+	  $field_transition[$field_id][$from][$to]['allowed'] = $this_transition['is_allowed'];
+	  $field_transition[$field_id][$from][$to]['assign_to'] = $this_transition['assign_to'];
+	  $field_transition[$field_id][$from][$to]['notification_list'] = $this_transition['notification_list'];
+	}
+    }
+  
+  # See which fields changed during the modification
+  # and if we must keep history then do it. Also add them to the update
+  # statement
   $changes = array();
   reset($vfl);
   while (list($field,$value) = each($vfl))
@@ -1461,6 +1488,39 @@ function trackers_data_handle_update ($group_id,
 	{ continue; }
 
       $old_value = db_result($result,0,$field);
+
+      # handle field transitions checks/changes
+      # yeupou--gnu.org 2004-09-12: where the hell $by_field_id is set???
+      $field_id = ($by_field_id ? $field : trackers_data_get_field_id($field));
+      $field_transition_cc = '';
+      if (array_key_exists($field_id, $field_transition)) 
+	{
+          # First check basic transition
+	  # And check multiple transition, override other transition
+	  if (array_key_exists($old_value, $field_transition[$field_id])||
+	      array_key_exists("any", $field_transition[$field_id])) 
+	    {
+	      if (array_key_exists("any", $field_transition[$field_id]) && array_key_exists($value, $field_transition[$field_id]["any"]))
+		{
+		  $field_transition_cc = $field_transition[$field_id]["any"][$value]['notification_list'];
+		  if ($field_transition[$field_id]["any"][$value]['assign_to'] != 100)
+		    {
+		      $transition_assigned_to = $field_transition[$field_id]["any"][$value]['assign_to'];
+		    }
+		}
+	      else if (array_key_exists($old_value, $field_transition[$field_id]) && array_key_exists($value, $field_transition[$field_id][$old_value])) 
+		{
+		  
+		  $field_transition_cc = $field_transition[$field_id][$old_value][$value]['notification_list'];
+		  if ($field_transition[$field_id][$old_value][$value]['assign_to'] != 100)
+		    {
+		      $transition_assigned_to = $field_transition[$field_id][$old_value][$value]['assign_to'];
+		    }
+		}
+		  
+	    }
+	}
+      
       $is_text = (trackers_data_is_text_field($field) || trackers_data_is_text_area($field));
       if  ($is_text)
 	{
@@ -1479,6 +1539,21 @@ function trackers_data_handle_update ($group_id,
 
       if ($differ)
 	{
+          # if assigned_to is the current field and differ, it must override
+          # transition motivated changes of assign_to
+          if ($field == 'assigned_to') 
+            {
+              $isset_assigned_to = true; 
+            }
+          
+
+          if ((trim($extra_addresses) != "") && (trim($field_transition_cc) != "")) 
+            {
+              $extra_addresses .= ", ";
+            }
+            $extra_addresses .= $field_transition_cc;
+          
+
 	  if ($is_text)
 	    {
 	      $upd_list .= "$field='".htmlspecialchars($value)."',";
@@ -1502,11 +1577,24 @@ function trackers_data_handle_update ($group_id,
 	}
     }
 
+  # Assigned_to is handled is a specific way if the change  is due to
+  # transitions: it won't override what was filled in the form.
+  # yeupou--gnu.org 2004-09-16: there's still a pending question: what happens
+  # if two contradictory orders are given, for instance if two fields changes
+  # require reassignation? Well, for now, let's assume that project admins
+  # will be clever enough.
+  if (!$isset_assigned_to && $transition_assigned_to != 0)
+    { 
+      $upd_list .= "assigned_to='$transition_assigned_to',";
+      trackers_data_add_history('assigned_to',$old_value = db_result($result,0,'assigned_to'),$transition_assigned_to,$item_id);
+    }
+
   # Details field history is handled a little differently. Followup comments
   # are added in the bug history along with the comment type.
   #
   # If a canned response is given it overrides anything typed in the followup
   # comment text area (aka details area).
+  # yeupou--gnu.org 2004-09-19: this behavior is more than questionnable.
   $details = $vfl['details'];
   if ($canned_response != 100)
     {
@@ -1577,6 +1665,7 @@ function trackers_data_handle_update ($group_id,
   # Finally, build the full SQL query and update the bug itself (if need be)
 
   $result = true;
+ dbg("UPD LIST: $upd_list");
   if ($upd_list)
     {
       dbg($upd_list);
@@ -1585,18 +1674,18 @@ function trackers_data_handle_update ($group_id,
 
       $sql="UPDATE ".ARTIFACT." SET $upd_list ".
 	 " WHERE bug_id='$item_id' AND group_id='$group_id'";
-
+      dbg($sql);
       $result=db_query($sql);
     }
 
   if (!$result)
     {
-      exit_error(_("Update failed."));
+      exit_error(_("Item Update failed"));
       return false;
     }
   else
     {
-      fb(_("Successfully Updated."));
+      fb(_("Item Successfully Updated"));
       return true;
     }
 }
@@ -1748,7 +1837,7 @@ function trackers_data_reassign_item ($item_id,
 						 true,
 						 true,
 						 false);
-	      $comment .= "<br>";
+	      $comment .= "<br />";
 	    }
 	}
 
@@ -1955,7 +2044,7 @@ function trackers_data_create_item($group_id,$vfl)
 
 
   $sql="INSERT INTO ".ARTIFACT." ($fixed_cols $vfl_cols) VALUES ($fixed_values $vfl_values)";
-  #echo "DBG - SQL insert bug: $sql";
+  dbg("DBG - SQL insert bug: $sql");
   $result=db_query($sql);
   $item_id=db_insertid($result);
 
@@ -2051,7 +2140,7 @@ function trackers_data_get_reports($group_id, $user_id)
 	$sql .= "(group_id=$group_id AND (user_id=$user_id OR scope='P')) OR ".
 	   "scope='S' ORDER BY scope,report_id";
       }
-  #echo "DBG sql report = $sql";
+  #print "DBG sql report = $sql";
   return db_query($sql);
 }
 
