@@ -2,12 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: mod.php,v 1.13 2004/06/28 10:30:44 yeupou Exp $
+# $Id: mod.php,v 1.14 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
 #  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#                          Yves Perrin <yves.perrin--at--cern.ch>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -42,6 +43,8 @@ if (db_numrows($result) > 0)
     { $item_name = "bug #".$item_id; }
   else
     { $item_name = ARTIFACT." #".$item_id; }
+  # Defines the item link
+  $item_link = utils_link("?func=detailitem&item_id=".$item_id, $item_name);
 
 
   # Prepare all the necessary fields in case the user wants to 
@@ -101,7 +104,7 @@ if (db_numrows($result) > 0)
 
   # ################################ Start the form
 
-  print '<h2>'.sprintf(_("<i>%s</i> overview:"), $item_name).' '.db_result($result,0,'summary').'</h2>';
+  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> overview:"), $item_link).' '.db_result($result,0,'summary').'</h2>';
 
   print '
     <form action="'.$PHP_SELF.'" method="post" enctype="multipart/form-data" name="item_form">
@@ -134,7 +137,11 @@ if (db_numrows($result) > 0)
       if ((!trackers_data_is_special($field_name) || $field_name=='summary' || $field_name=='details') &&
 	  trackers_data_is_used($field_name)) 
 	{
-				   
+	  # if the submitter was anonymous, print the originator email field
+	  if ($field_name != 'originator_email' ||
+	      ($field_name == 'originator_email' && db_result($result,0,'submitted_by') == '100'))
+	    {
+	      
 	  # display the bug field
 	  # if field size is greatest than max_size chars then force it to
 	  # appear alone on a new line or it won't fit in the page
@@ -158,16 +165,18 @@ if (db_numrows($result) > 0)
 	  if ($field_name =='details' || 
 	      $mbcheck && $field_name =='status_id' ||
 	      $mbcheck && $field_name =='assigned_to' ||
-	      $mbcheck && $field_name =='priority') 
+	      $mbcheck && $field_name =='priority' ||
+	      $mbcheck && $field_name =='originator_email') 
 	    { 
 	      dbg("field_name:$field_name is read-only, mbcheck_is_not_manager:$mbcheck_is_not_manager");
 	      $value = utils_make_links(trackers_field_display($field_name,$group_id,$field_value,false,false,true),$group_id);
 	    }
 	  else
 	    {
-	      $value = trackers_field_display($field_name,$group_id,$field_value,false,false);
+              $value = trackers_field_display($field_name,$group_id,$field_value,false,false,"","","","","","",true);
 	    }
 	  $star = (trackers_data_is_empty_ok($field_name) ? '':'<font class="error"> *</font>');
+ 
 
 	  if ($sz > $max_size) 
 	    {
@@ -186,6 +195,7 @@ if (db_numrows($result) > 0)
 	      $i++;
 	      print ($i % $fields_per_line ? '':"\n</tr>");
 	    }
+         }
 	}
     }
       
@@ -194,16 +204,17 @@ if (db_numrows($result) > 0)
 
   # ################################ Shortcuts
 
-  print '<h2>'.sprintf(_("<i>%s</i> details:"), $item_name).'</h2>';
-  print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br>';  
-  print '&nbsp;&nbsp;- <a href="#attached">'._("Attached Files").'</a><br>';
-  print '&nbsp;&nbsp;- <a href="#cc">'._("Mail Notification Carbon-Copy List").'</a><br>';
-  print '&nbsp;&nbsp;- <a href="#dependencies">'._("Dependencies").'</a><br>';
+  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> details:"), $item_link).'</h2>';
+  print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br />';  
+  print '&nbsp;&nbsp;- <a href="#attached">'._("Attached Files").'</a><br />';
+  print '&nbsp;&nbsp;- <a href="#cc">'._("Mail Notification Carbon-Copy List").'</a><br />';
+  print '&nbsp;&nbsp;- <a href="#dependencies">'._("Dependencies").'</a><br />';
   if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3'))
     {
-      print '&nbsp;&nbsp;- <a href="#reassign">'._("Reassign this item").'</a><br>'; 
+      print '&nbsp;&nbsp;- <a href="#reassign">'._("Reassign this item").'</a><br />'; 
     }
 
+  print '&nbsp;&nbsp;- <a href="#history">'._("History").'</a><br />';
   print '<p>&nbsp;</p>';
        
   # ################################ Comments 
@@ -242,10 +253,10 @@ if (db_numrows($result) > 0)
 
   print '<h3>'.html_anchor(_("Attached Files"), "attached").'</h3>';
   
-  print '<font class="preinput"> '._("Attach File:").'</font><br>
+  print '<font class="preinput"> '._("Attach File:").'</font><br />
       &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40">
-      <br>
-      <font class="preinput">'._("File Description:").'</font><br>
+      <br />
+      <font class="preinput">'._("File Description:").'</font><br />
       &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255">
       </p><p>';
 	  
@@ -260,10 +271,10 @@ if (db_numrows($result) > 0)
   printf (_("(Note: for %s users, you can use their login name rather than their email addresses.)"), $GLOBALS['sys_name']);
 
   print '<p><font class="preinput">'
-    ._("Add an email address that should receive carbon copies of updates of this item:").'</font><br>&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="40" value="'.$add_cc.'">&nbsp;&nbsp;&nbsp;
-        <br>
+    ._("Add an email address that should receive carbon copies of updates of this item:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="40" value="'.$add_cc.'">&nbsp;&nbsp;&nbsp;
+        <br />
         <font class="preinput">'
-    ._("Comment:").'</font><br>&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255" value="'.$cc_comment.'">';
+    ._("Comment:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255" value="'.$cc_comment.'">';
   print '<p></p>';
   show_item_cc_list($item_id, $group_id);
 
@@ -282,20 +293,20 @@ if (db_numrows($result) > 0)
       print _("New search, in case the previous one was not satisfactory (to fill a dependancy against):");
     }
 
-  print '</font><br>
-      &nbsp;&nbsp;&nbsp;<input type="text" name="depends_search" size="40" maxlength="255"><br>';
+  print '</font><br />
+      &nbsp;&nbsp;&nbsp;<input type="text" name="depends_search" size="40" maxlength="255"><br />';
   
   
   function specific_depends_on_artifact ($art, $content)
     { 
       # Function too trivial to generalized in usual includes.
       if (ARTIFACT == $art) 
-	{ $checked = " selected"; }
+	{ $checked = " selected=\"selected\""; }
       print '<option value="'.$art.'"'.$checked.'>'.$content.'</option>'; 
       unset($checked);
     }
       
-  print '<font class="preinput">'._("Of:").'</font><br>
+  print '<font class="preinput">'._("Of:").'</font><br />
 &nbsp;&nbsp;&nbsp;<select name="depends_search_only_artifact">'
 .'<option value="all">'._("any Trackers").'</option>';
 
@@ -308,7 +319,7 @@ if (db_numrows($result) > 0)
   print _("of");
   print ' <select name="depends_search_only_project">'
    .'<option value="any">'._("any Project").'</option>'
-   .'<option value="notany" selected>'._("this Project Only").'</option>
+   .'<option value="notany" selected="selected">'._("this Project Only").'</option>
    </select>&nbsp;';
 
   if (!$depends_search) 
@@ -349,7 +360,7 @@ if (db_numrows($result) > 0)
 		{ $search_without_group_id = 0; }
 	      else
 		{ $search_without_group_id = 1; }
-	      
+
 	      $result_search = search_run($depends_search, $tracker, 0);
 	      $success = db_numrows($result_search) + $success;
 
@@ -363,7 +374,7 @@ if (db_numrows($result) > 0)
 			{			  
 			  # Right now only print id, summary and group.
 			  # We may change that depending on users feedback.
-			  print '<br>';
+			  print '<br />';
 			  print '&nbsp;&nbsp;&nbsp;<input type="checkbox" name="dependent_on_'.$tracker.'[]" value="'.$res_id.'">['.$tracker.' #'.$res_id.'] '.$res_summary.', '._("group").' '.group_getname($res_group);
 			}
 		    }
@@ -372,7 +383,7 @@ if (db_numrows($result) > 0)
 	}
       if (!$success)
 	{
-	  print '<br><font class="warn">';
+	  print '<br /><font class="warn">';
 	  print _("None found. Please note that only search words of more than three characters are valid.");
 	  print '</font>';
 	}
@@ -398,7 +409,7 @@ if (db_numrows($result) > 0)
       print '<h3>'.html_anchor(_("Reassign this item"), "reassign").'</h3>';
         
       print '<p><font class="preinput">'
-	._("Move to the:").'</font><br>&nbsp;&nbsp;&nbsp;';
+	._("Move to the:").'</font><br />&nbsp;&nbsp;&nbsp;';
 
       function specific_reassign_artifact ($art, $content)
 	{
@@ -415,7 +426,7 @@ if (db_numrows($result) > 0)
       specific_reassign_artifact("patch", _("Patch Tracker"));
       print '</select>';
 
-      print '<br><br>
+      print '<br /><br />
         <font class="preinput">';
 
       if (!$reassign_change_project_search) 
@@ -427,7 +438,7 @@ if (db_numrows($result) > 0)
 	  print _("New search, in case the previous one was not satisfactory (to reassign the item to another project):");
 	}
 
-      print '</font><br>&nbsp;&nbsp;&nbsp;<input type="text" name="reassign_change_project_search" size="40" maxlength="255">';
+      print '</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="reassign_change_project_search" size="40" maxlength="255">';
       if (!$reassign_change_project_search) 
 	{ 
 	  print ' <input type="submit" name="submit" value="'._("Search").'">'; 
@@ -449,7 +460,7 @@ if (db_numrows($result) > 0)
 
 	  # Print a null-option, someone may change his mine without having
 	  # to use the back button of his browser.
-	  print '<br>&nbsp;&nbsp;&nbsp;<input type="radio" name="reassign_change_project" value="0" checked> '._("Do not reassign to another project.");
+	  print '<br />&nbsp;&nbsp;&nbsp;<input type="radio" name="reassign_change_project" value="0" checked> '._("Do not reassign to another project.");
 	  
 	  unset($success);
 	  $result_search = search_run($reassign_change_project_search, "soft", 0);
@@ -463,7 +474,7 @@ if (db_numrows($result) > 0)
 		  # Not reassigning to itself.
 		  if ($res_unix_group_name != $group_name)
 		    {			  
-		      print '<br>';
+		      print '<br />';
 		      print '&nbsp;&nbsp;&nbsp;<input type="radio" name="reassign_change_project" value="'.$res_unix_group_name.'"> ['.$res_unix_group_name.', #'.$res_group_id.'] '.$res_group_name;
 		    }
 		}
@@ -471,7 +482,7 @@ if (db_numrows($result) > 0)
 	  
 	  if (!$success)
 	    {
-	      print '<br><font class="warn">';
+	      print '<br /><font class="warn">';
 	      print _("None found. Please note that only search words of more than three characters are valid.");
 	      print '</font>';
 	    }
