@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: utils.php,v 1.63 2004/06/30 14:10:51 yeupou Exp $
+# $Id: utils.php,v 1.64 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -64,6 +64,19 @@ function utils_makereal ($data, $string="%PROJECT", $replacement=0)
   return ereg_replace($string, $replacement, $data);
 }
 
+# Add unavailable css class to a link if required
+function utils_link ($url, $title, $defaultclass=0, $available=1)
+{
+  if (!$available)
+    { $defaultclass = 'unavailable'; }
+
+  $return = '<a href="'.$url.'"';
+
+  if ($defaultclass) 
+    { $return .= ' class="'.$defaultclass.'"'; }
+  $return .= '>'.$title.'</a>';
+  return $return;
+}
 
 # This function returns a string of the date $value with the format $format
 # and if this date is not set, return the default value $default_value
@@ -98,7 +111,7 @@ function utils_date_to_unixtime ($date)
     { return array(0,false); }
   list(,$year,$month,$day) = $match;
   $time = mktime(0, 0, 0, $month, $day, $year);
-  #echo "<br>DBG Matching date $date -> year $year, month $month,day $day -> time = $time<br>";
+  dbg("DBG Matching date $date -> year $year, month $month,day $day -> time = $time<br />");
   return array($time,true);
 }
 
@@ -436,24 +449,35 @@ function utils_registration_history ($unix_group_name)
 
 function show_priority_colors_key()
 {
-  print '<br><br><table border=0><tr>';
-  echo '<td><b>'._("Priority Colors").":</b> &nbsp;&nbsp;&nbsp;</td>\n";
+  print '<p class="smaller">';
+  print _("Open Items Priority Colors:")."<br />&nbsp;&nbsp;&nbsp;\n";
 
   for ($i=1; $i<10; $i++)
     {
-      print '<td class="'.get_priority_color($i).'">'.$i."</td>\n";
+      print '<span class="'.utils_get_priority_color($i).'">&nbsp;'.$i.'&nbsp;</span>'."\n";
     }
-  print  "</tr></table>\n";
+  
+  print '<br />';
+  print _("Closed Items Priority Colors:")."<br />&nbsp;&nbsp;&nbsp;\n";
+
+  for ($i=11; $i<20; $i++)
+    {
+      print '<span class="'.utils_get_priority_color($i).'">&nbsp;'.($i-10).'&nbsp;</span>'."\n";
+    }
+
+  print  "</p>";
 }
 
+function get_priority_color ($index, $closed="")
+{ return utils_get_priority_color($index, $closed); }
 
-function get_priority_color ($index)
+
+function utils_get_priority_color ($index, $closed="")
 {
-  /*
-		Return the color value for the index that was passed in
-		(defined in $sys_urlroot/themes/<selected theme>/theme.php)
-  */
   global $bgpri;
+  # If the item is closed, add ten to the index number to get closed colors
+  if ($closed == 3)
+    { $index = $index + 10; }
 
   return $bgpri[$index];
 }
@@ -465,17 +489,17 @@ function build_priority_select_box ($name="priority", $checked_val="5")
 		The name of this select box is optional and so is the default checked value
   */
 
-  echo "<select name=\"$name\">\n";
-  echo '<option value="1"'.($checked_val=="1" ?" selected":"").'>1 - '._("Lowest").'</option>';
-  echo '<option value="2"'.($checked_val=="2" ?" selected":"").'>2</option>';
-  echo '<option value="3"'.($checked_val=="3" ?" selected":"").'>3</option>';
-  echo '<option value="4"'.($checked_val=="4" ?" selected":"").'>4</option>';
-  echo '<option value="5"'.($checked_val=="5" ?" selected":"").'>5 - '._("Medium").'</option>';
-  echo '<option value="6"'.($checked_val=="6" ?" selected":"").'>6</option>';
-  echo '<option value="7"'.($checked_val=="7" ?" selected":"").'>7</option>';
-  echo '<option value="8"'.($checked_val=="8" ?" selected":"").'>8</option>';
-  echo '<option value="9"'.($checked_val=="9" ?" selected":"").'>9 - '._("Highest").'</option>';
-  echo '</select>';
+  print "<select name=\"$name\">\n";
+  print '<option value="1"'.($checked_val=="1" ?" selected":"").'>1 - '._("Lowest").'</option>';
+  print '<option value="2"'.($checked_val=="2" ?" selected":"").'>2</option>';
+  print '<option value="3"'.($checked_val=="3" ?" selected":"").'>3</option>';
+  print '<option value="4"'.($checked_val=="4" ?" selected":"").'>4</option>';
+  print '<option value="5"'.($checked_val=="5" ?" selected":"").'>5 - '._("Medium").'</option>';
+  print '<option value="6"'.($checked_val=="6" ?" selected":"").'>6</option>';
+  print '<option value="7"'.($checked_val=="7" ?" selected":"").'>7</option>';
+  print '<option value="8"'.($checked_val=="8" ?" selected":"").'>8</option>';
+  print '<option value="9"'.($checked_val=="9" ?" selected":"").'>9 - '._("Highest").'</option>';
+  print '</select>';
 
 
 }
@@ -490,16 +514,16 @@ function utils_buildcheckboxarray($options,$name,$checked_array)
 
   for ($i=1; $i<=$option_count; $i++)
     {
-      echo '
+      print '
 			<BR><INPUT type="checkbox" name="'.$name.'" value="'.$i.'"';
       for ($j=0; $j<$checked_count; $j++)
 	{
 	  if ($i == $checked_array[$j])
 	    {
-	      echo ' CHECKED';
+	      print ' CHECKED';
 	    }
 	}
-      echo '> '.$options[$i];
+      print '> '.$options[$i];
     }
 }
 
@@ -532,7 +556,7 @@ function utils_graph_result ($result,$title)
 
   if ((!$result) || ($rows < 1))
     {
-      echo 'None Found.';
+      print 'None Found.';
     }
   else
     {
@@ -616,8 +640,8 @@ function utils_graph_it ($name_string,$value_string,$title)
   $title_arr=array();
   $title_arr[]=$title;
 
-  echo html_build_list_table_top ($title_arr);
-  echo '<TR><TD>';
+  print html_build_list_table_top ($title_arr);
+  print '<TR><TD>';
   /*
 		Create an associate array to pass in. I leave most of it blank
   */
@@ -653,7 +677,7 @@ function utils_graph_it ($name_string,$value_string,$title)
 
   html_graph($name_string,$value_string,$bars,$vals);
 
-  echo '
+  print '
 		</TD></TR></TABLE>
 		<!-- end outer graph table -->';
 }
@@ -677,28 +701,28 @@ function utils_show_result_set ($result,$title="Untitled",$linkify=false)
     $rows  =  db_numrows($result);
     $cols  =  db_numfields($result);
 
-    echo '
+    print '
 			<TABLE BORDER="0" WIDTH="100%">';
 
     /*  Create the title  */
 
-    echo '
+    print '
 		<TR BGCOLOR="'.$HTML->COLOR_HTMLBOX_TITLE.'">
 		<TD COLSPAN="'.$cols.'"><B><FONT COLOR="'. $HTML->FONTCOLOR_HTMLBOX_TITLE .'">'.$title.'</FONT></B></TD></TR>';
 
     /*  Create  the  headers  */
-    echo '
+    print '
 			<tr>';
     for ($i=0; $i < $cols; $i++)
       {
-	echo '<td><B>'.db_fieldname($result,  $i).'</B></TD>';
+	print '<td><B>'.db_fieldname($result,  $i).'</B></TD>';
       }
-    echo '</tr>';
+    print '</tr>';
 
     /*  Create the rows  */
     for ($j = 0; $j < $rows; $j++)
       {
-	echo '<TR class="'. html_get_alt_row_color($j) .'">';
+	print '<TR class="'. html_get_alt_row_color($j) .'">';
 	for ($i = 0; $i < $cols; $i++)
 	  {
 	    if ($linkify && $i == 0)
@@ -730,16 +754,16 @@ function utils_show_result_set ($result,$title="Untitled",$linkify=false)
 	      {
 		$link = $linkend = '';
 	      }
-	    echo '<td>'.$link . db_result($result,  $j,  $i) . $linkend.'</td>';
+	    print '<td>'.$link . db_result($result,  $j,  $i) . $linkend.'</td>';
 
 	  }
-	echo '</tr>';
+	print '</tr>';
       }
-    echo '</table>';
+    print '</table>';
   }
   else
     {
-      echo db_error();
+      print db_error();
     }
 }
 
@@ -754,12 +778,11 @@ function utils_cleanup_emails ($addresses)
 # login name
 function utils_normalize_email ($address)
 {
-  global $sys_users_host;
   $address = utils_cleanup_emails($address);
   if (validate_email($address))
     return $address;
   else
-    return $address."@$sys_users_host";
+    return $address."@".$GLOBALS['sys_default_domain'];
 }
 
 
@@ -774,6 +797,7 @@ function utils_antispam_email ($address)
 function utils_split_emails($addresses)
 {
   $addresses = utils_cleanup_emails($addresses);
+  $addresses = ereg_replace(";", ",", $addresses);
   return split(',',$addresses);
 }
 
@@ -831,8 +855,8 @@ function dbg ($msg)
 {
   if ($GLOBALS['sys_debug_on'])
     {
-      $GLOBALS['debug'] .= "<br><br>latest func called: ".ereg_replace($_SERVER["DOCUMENT_ROOT"].$GLOBALS['sys_home'], "",$GLOBALS['sys_debug_where']);
-      $GLOBALS['debug'] .= "<br>msg: $msg";
+      $GLOBALS['debug'] .= "<br /><br />latest func called: ".ereg_replace($_SERVER["DOCUMENT_ROOT"].$GLOBALS['sys_home'], "",$GLOBALS['sys_debug_where']);
+      $GLOBALS['debug'] .= "<br />msg: $msg";
     }
 }
 
@@ -861,18 +885,25 @@ function fb ($msg, $error=0)
       $msg = substr($msg, 0, (strlen($msg)-1));
     }
 
+
   # First letter capitalized, that's all
-  $msg = strtoupper(substr($msg, 0, 1)).strtolower(substr($msg, 1, strlen($msg))).' [#'.$GLOBALS['feedback_count'].']; ';
+  $msg = strtoupper(substr($msg, 0, 1)).strtolower(substr($msg, 1, strlen($msg)));
+
+  if ($GLOBALS['sys_debug_on']) 
+    { 
+      $msg .= ' [#'.$GLOBALS['feedback_count'].']';
+      dbg("Add feedback #".$GLOBALS['feedback_count']);
+    }
+
+  $msg .= _(";").' ';
 
   # feed
   if (!$error)
     {
-      dbg("Add feedback #".$GLOBALS['feedback_count']);
       $GLOBALS['feedback'] .= $msg;
     }
   else
     {
-      dbg("Add feedback #".$GLOBALS['feedback_count']);
       $GLOBALS['ffeedback'] .= $msg;
     }
 }
