@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.57 2004/06/26 08:02:16 yeupou Exp $
+# $Id: index.php,v 1.58 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -105,79 +105,52 @@ if (user_isloggedin())
   site_user_header(array('toptab'=>'my'));
   # we get site-specific content
   utils_get_content("my/index");
+  print "<br /><br />\n\n";
 
   if ($feedback)
     {
-      echo $feedback;
+      print $feedback;
     }
 
-  echo '<table width="100%" border="0"><tr><td valign="top" width="50%">';
-  # Tasks assigned to me
-  echo $HTML->box1_top(_("My Tasks"));
-  my_artifact_items("task");
-  echo $HTML->box1_bottom();
-  echo '<br><br>';
-
-  # SRs assigned to or submitted by me
-  echo $HTML->box1_top(_("My Support Requests"));
-  my_artifact_items("support");
-  echo $HTML->box1_bottom();
-  echo '<br><br>';
-
-  # Bugs assigned to or submitted by me
-  echo $HTML->box1_top(_("My Bugs"));
-  my_artifact_items("bugs");
-  echo $HTML->box1_bottom();
-  echo '<br><br>';
-
-  # Patch assigned to me
-  echo $HTML->box1_top(_("My Patches"));
-  my_artifact_items("patch");
-  echo $HTML->box1_bottom();
-  echo '<br><br>';
-
-  /*
-	 Change from the left to the right of the page
-  */
-  echo '</td><td valign="top" width="50%">';
-
+ ################ RIGHT PART ############################
 
+  print html_splitpage(1);
 
   # Bookmarks
-  echo $HTML->box1_top(_("My Bookmarks"));
+  print $HTML->box1_top(_("My Bookmarks"));
 
   $result = db_query("SELECT bookmark_url, bookmark_title, bookmark_id from user_bookmarks where ".
 		     "user_id='". user_getid() ."' ORDER BY bookmark_title");
   $rows=db_numrows($result);
   if (!$result || $rows < 1)
     {
-      echo _("You currently do not have any bookmarks saved");
-      echo db_error();
+      print _("I currently do not have any bookmarks saved");
+      print db_error();
     }
   else
     {
 
-      echo '<table>';
+      print '<table>';
       for ($i=0; $i<$rows; $i++)
 	{
-	  echo '<tr class="'. utils_get_alt_row_color($i) .'"><td width="99%">';
-	  echo '
+	  print '<tr class="'. utils_get_alt_row_color($i) .'"><td width="99%">';
+	  print '
                                            <b><a href="'. db_result($result,$i,'bookmark_url') .'">'.
 	    db_result($result,$i,'bookmark_title') .'</a></b> '.
 	    '<a href="'.$GLOBALS['sys_home'].'my/bookmark_edit.php?bookmark_id='. db_result($result,$i,'bookmark_id') .'">[Edit]</a></td>'.
 	    '<td><a href="'.$PHP_SELF.'?func=delbookmark&amp;bookmark_id='. db_result($result,$i,'bookmark_id') .
 	    '" onClick="return confirm(\''._("Delete this bookmark?").'\')">'.
-	    '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="delete"></a></td></tr>';
+	    '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Delete this bookmark?").'" /></a></td></tr>';
 	}
-      echo '</table>';
+      print '</table>';
     }
-  echo $HTML->box1_bottom();
-  echo '<br><br>';
+  print $HTML->box1_bottom();
+  print '<br /><br />';
 
 
 
   # Forums that are actively monitored
-  echo $HTML->box1_top(_("Monitored Forums"));
+  print $HTML->box1_top(_("Monitored Forums"));
 
   $sql="SELECT groups.group_id, groups.group_name ".
      "FROM groups,forum_group_list,forum_monitored_forums ".
@@ -189,11 +162,11 @@ if (user_isloggedin())
   $rows=db_numrows($result);
   if (!$result || $rows < 1)
     {
-      echo '<p>'._("You are not monitoring any forums.").'</p>';
-      echo '<p>'._("If you monitor forums, you will be sent new posts in the form of an email, with a link to the new message.");
-      echo '<p>'._("You can monitor forums by clicking 'Monitor Forum' in any given discussion forum.");
-      echo '<br>&nbsp;';
-      echo db_error();
+      print '<p>'._("I am not monitoring any forums.").'</p>';
+      print '<p>'._("If I monitor forums, I will be sent new posts in the form of an email, with a link to the new message.");
+      print '<p>'._("I can monitor forums by clicking 'Monitor Forum' in any given discussion forum.");
+      print '<br />&nbsp;';
+      print db_error();
     }
   else
     {
@@ -235,52 +208,51 @@ if (user_isloggedin())
 		     '<td align="middle"><a href="'.$GLOBALS['sys_home'].'forum/monitor.php?forum_id='.$group_forum_id.
 		     '" onClick="return confirm(\''._("Stop monitoring this Forum?").'\')">'.
 		     '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" '.
-		     'border="0" alt="stop monitoring"></a></td></tr>';
+		     'border="0" alt="'._("Stop monitoring this Forum?").'" /></a></td></tr>';
 		}
 	    }
 
 	  $html_hdr .= my_item_count($rows2,$count_new).'</td></tr>';
-	  echo $html_hdr.$html;
+	  print $html_hdr.$html;
 	}
 
-      echo '<TR><TD COLSPAN="2">&nbsp;</TD></TR>';
+      print '<TR><TD COLSPAN="2">&nbsp;</TD></TR>';
     }
-  echo $HTML->box1_bottom();
-  echo '<br><br>';
-
+  print $HTML->box1_bottom();
+  print '<br /><br />';
 
   # Watching other users.
 
-  echo $HTML->box1_top(_("Watched Partners"));
+  print $HTML->box1_top(_("Watched Partners"));
 
   $result = trackers_data_get_watchees(user_getid());
   $rows=db_numrows($result);
 
   if (!$result || $rows < 1)
     {
-      echo '<p>'._("You are not watching any partners.").'</p>';
-      echo '<p>'.sprintf(_("If you want to be the backup of someone when they're away from the office, or if you need to do the QA to all their activities on a project, %s can send their email notification to you also."),$GLOBALS['sys_name']);
-      echo '</p><p>'._("You can watch someone clicking 'Watch Partner' in any project memberlist page (you must be member of that project, indeed).");
-      echo '<br>&nbsp;';
-      echo db_error();
+      print '<p>'._("I am not watching any partners.").'</p>';
+      print '<p>'._("Watching a partner (receiving a copy of all the notification sent to him) permits to be his backup when he is away from the office, or to do QA to all his/her activities on a project.");
+      print '</p><p>'._("To watch someone, click 'Watch Partner' in any project memberlist page (membership to that project is required, indeed).");
+      print '<br />&nbsp;';
+      print db_error();
     }
   else
     {
 
-      echo '<table>';
+      print '<table>';
       for ($i=0; $i<$rows; $i++)
 	{
-	  echo '<tr class="'.utils_get_alt_row_color($i).'"><td width="99%"><font class="bold">'.
+	  print '<tr class="'.utils_get_alt_row_color($i).'"><td width="99%"><font class="bold">'.
 	    utils_user_link(user_getname(db_result($result, $i, 'watchee_id')), user_getrealname(db_result($result, $i, 'watchee_id'))).
 	    '</font> <font class="smaller">['.group_getname(db_result($result, $i, 'group_id')).']'.
 	    '</font>';
 
-	  echo '</td>'.
+	  print '</td>'.
 	    '<td><a href="'.$PHPSELF.'?func=delwatchee&amp;group_id='.db_result($result,$i,'group_id').'&amp;watchee_id='.db_result($result, $i, 'watchee_id').
 	    '" onClick="return confirm(\''._("Stop watching this user?").'\')">'.
-	    '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="remove"></a></td></tr>';
+	    '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Stop watching this user?").'" /></a></td></tr>';
 	}
-      echo '</table>';
+      print '</table>';
 
     }
 
@@ -296,25 +268,60 @@ if (user_isloggedin())
       $watchers = substr($watchers,0,-2); # remove extra comma at the end
       $watchers .= ".";
 
-      echo '<p>';
-      printf (_("For your information your own notifications are currently watched by: %s"),$watchers);
-      echo '</p>';
+      print '<p>';
+      printf (_("My own notifications are currently watched by: %s"),$watchers);
+      print '</p>';
     }
   else
     {
-      echo '<p>'._("For your information nobody is currently watching your own notifications.").'</p>';
+      print '<p>'._("Nobody is currently watching my own notifications.").'</p>';
     }
 
-  echo $HTML->box1_bottom();
+  print $HTML->box1_bottom();
 
 
+ ################ LEFT PART ############################
+
+  print html_splitpage(2);
+
+  global $lessthanzero;
+  $lessthanzero = 0; 
+
+  # Tasks assigned to me
+  print $HTML->box_top(_("My Tasks"));
+  my_artifact_items("task");
+  print $HTML->box_bottom($lessthanzero);
+  print '<br /><br />'."\n";
+  $lessthanzero = 0; 
+
+  # SRs assigned to or submitted by me
+  print $HTML->box_top(_("My Support Requests"));
+  my_artifact_items("support");
+  print $HTML->box_bottom($lessthanzero);
+  print '<br /><br />'."\n";
+  $lessthanzero = 0; 
+
+  # Bugs assigned to or submitted by me
+  print $HTML->box_top(_("My Bugs"));
+  my_artifact_items("bugs");
+  print $HTML->box_bottom($lessthanzero);
+  print '<br /><br />'."\n";
+  $lessthanzero = 0; 
+
+  # Patch assigned to me
+  print $HTML->box_top(_("My Patches"));
+  my_artifact_items("patch");
+  print $HTML->box_bottom($lessthanzero);
+  print '<br /><br />'."\n";
+  $lessthanzero = 0; 
+
+
+  print html_splitpage(3);
 
   # End
-  echo '</td></tr><tr><td colspan="2">';
 
-  echo show_priority_colors_key();
+  print "\n\n".show_priority_colors_key();
 
-  echo '</td></tr></table>';
 
   $HTML->footer(array());
 
