@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: editjob.php,v 1.19 2004/06/26 08:02:16 yeupou Exp $
+# $Id: editjob.php,v 1.20 2004/09/22 08:11:52 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -186,19 +186,19 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
 		<input type="hidden" name="group_id" value="'.$group_id.'">
 		<input type="hidden" name="job_id" value="'.$job_id.'">
 		<b>'
-	._("Category:").'</b><br>'
+	._("Category:").'</b><br />'
 	. people_job_category_box('category_id',db_result($result,0,'category_id')) .'
 		<p>
 		<b>'
-	._("Status").':</b><br>'
+	._("Status").':</b><br />'
 	. people_job_status_box('status_id',db_result($result,0,'status_id')) .'
 		<p>
 		<b>'
-	._("Short Description:").'</b><br>
+	._("Short Description:").'</b><br />
 		<input type="text" name="title" value="'. db_result($result,0,'title') .'" size="40" maxlength="60">
 		<p>
 		<b>'
-	._("Long Description:").'</b><br>
+	._("Long Description:").'</b><br />
 		<textarea name="description" rows="10" cols="60" wrap="soft">'. db_result($result,0,'description') .'</textarea>
 		<p>
 		<input type="submit" name="update_job" value="'._("Update Descriptions").'">
