@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: Groups.pm,v 1.20 2004/02/08 16:27:25 yeupou Exp $
+# $Id: Groups.pm,v 1.21 2004/09/20 11:40:13 beuc Exp $
 #
 #
 #
@@ -82,12 +82,15 @@ sub GetGroupList {
 
 ## Delete a group account. This function should be used carrefully.
 # arg1 : which group name
+# returns: 1 if the group was deleted, 0 if it was not
 sub DeleteGroup {    
-    return $dbd->do("DELETE FROM groups WHERE unix_group_name='".$_[0]."'") if $_[0];
+    return ($dbd->do("DELETE FROM groups WHERE unix_group_name='".$_[0]."'") >= 1) if $_[0];
 }
 
 ## Delete several group accounts. This function should be used carrefully.
 # arg1 : a criterion
+# returns: the number (real) of deleted rows, undef on error - check
+#          the DBI documentation
 sub DeleteGroups {    
     return $dbd->do("DELETE FROM groups WHERE ".$_[0]) if $_[0];
 }
